% process_MVP_CTD_data
% =========================================================================
%
% USAGE:
%  Alter the pathnames where indicated in the comment line and then run.
%  All required data is loaded.
%
% DESCRIPTION:
%  Filters the pressure, temperature and conductivity data.  Applies the
%  lag to conductivity that was previously determined using
%  'calc_lag_MVPdata'.  Calculates salinity and sigma-t.  Averages results
%  into 1 db bins.
%
%  Salinity and sigmat are calculated using the GSW Oceanographic Toolbox -
%  Thermodynamic Equation of Seawater 2010 (TEOS-10) available from:
%  http://www.teos-10.org/software.htm
%
%
% OUTPUT
%  A structure array of MVP downcasts containing metadata, pressure,
%  temperature, conductivity, salinity, sigmat, chl conc and LOPC counts.
%
% AUTHOR:
%  Dr. Susanne Craig, Bedford Institute of Oceanography (BIO)
%  Adapted from code written by Dr. Susanne Craig & Dr. Dave Hebert (BIO)
%
% VERSION NUMBER:
% 1.0 (25th June 2013)
% 1.1 (3rd Dec 2013)
%
% =========================================================================

clear
close all
clc

% Change pathnames as appropriate
addpath(genpath('/Users/scraig/Documents/Ross Sea/MVP/final MVP code'))
load '/Users/scraig/Documents/Ross Sea/MVP/MVPrawData' % <==
path2save = '/Users/scraig/Documents/Ross Sea/MVP'; % <==

%% Filter pressure, temperaure and conductivity before lagging

fp = 0.16; % Filter time constant for pressure (s). This value suggested in Seabird processing manual
sp = 1/25;  % CTD sample period. The AML microCTD samples at 25 Hz.
ftc = 0.5; %  Filter time constant (s) for temperature and conductivity

for n = 1:length(MVPd)
    presFilt = seabirdFilter(MVPd(n,1).pres, fp, sp);
    condFilt = seabirdFilter(MVPd(n,1).cond, ftc, sp);
    tempFilt = seabirdFilter(MVPd(n,1).temp, ftc, sp);
    
    lag = 4; % Mean of the lags obtained from calc_lag_MVPdata.m
    condFiltLag = lagmatrix(condFilt, lag);
    
    % New seawater toolbox ################################################
    % Calculate salinity
    % sal = gsw_SP_from_C(condFiltLag, tempFilt, presFilt); % New toolbox
    
    %     % Calculate density
    %     % 1. Calculate absolute salinity from PSU
    %     SA = nan(size(MVPd(n,1).pres));
    %     in_ocean = nan(size(MVPd(n,1).pres));
    %     for kk = 1:size(sal,1)
    %         [SA(kk,1), in_ocean(kk,1)] = gsw_SA_from_SP(sal(kk), presFilt(kk), MVPd(n,1).lon, MVPd(n,1).lat);
    %     end
    %     % 2. Calculate conservative temperature
    %     CT = gsw_CT_from_t(SA, tempFilt, presFilt);
    %
    %     % 3. Calculate potential density, i.e. density with respect to reference
    %     % pressure, which in this case we will specify to be 0 dB
    %     sigma_theta = gsw_rho(SA, CT, 0) - 1000.;
    
    
    % Old seawater toolbox ################################################
    sal = sw_salt(condFiltLag/sw_c3515, tempFilt, presFilt);
    potDens = sw_pden(sal, tempFilt, presFilt, 0.)-1000.;
    sigma_t = sw_dens(sal, tempFilt, 0.)-1000.;
    
    % Write to structure
    MVPd(n,1).presFilt = presFilt;
    MVPd(n,1).tempFilt = tempFilt;
    MVPd(n,1).condFilt = condFilt;
    MVPd(n,1).condFiltLag = condFiltLag;
    MVPd(n,1).sal = sal;
    MVPd(n,1).potDens = potDens;
    MVPd(n,1).sigmat = sigma_t;
    %     MVPd(n,1).SA = SA;
    %     MVPd(n,1).CT = CT;
    
    clear presFilt condFilt tempFilt condFiltLag sal potDens sigma_t
  
end

%% Bin average into 1 dbar bins

for n = 1:length(MVPd)
    
    % Add ancillary data
    MVP(n,1).bottomDepth = MVPd(n,1).bottomDepth;
    MVP(n,1).lat = MVPd(n,1).lat;
    MVP(n,1).lon = MVPd(n,1).lon;
    MVP(n,1).daten = MVPd(n,1).daten;
    
    pmin = round(min(MVPd(n,1).presFilt));
    pmax = round(max(MVPd(n,1).presFilt));
    
    i = 0;
    for p = pmin:1:pmax
        i = i+1;
        MVP(n,1).pres(i,:) = p;
        k = find(((MVPd(n,1).presFilt > p-0.5) & (MVPd(n,1).presFilt <= p+0.5)) == 1);
        
        MVP(n,1).temp(i,:) = nanmean(MVPd(n,1).tempFilt(k));
        MVP(n,1).cond(i,:) = nanmean(MVPd(n,1).condFilt(k));
        MVP(n,1).sal(i,:) = nanmean(MVPd(n,1).sal(k));
        % MVP(n,1).SA(i,:) = nanmean(MVPd(n,1).SA(k));
        % MVP(n,1).CT(i,:) = nanmean(MVPd(n,1).CT(k));
        MVP(n,1).sigmat(i,:) = nanmean(MVPd(n,1).sigmat(k));
        % MVP(n,1).sigma_theta(i,:) = nanmean(MVPd(n,1).sigma_theta(k));
        MVP(n,1).chl(i,:) = nanmean(MVPd(n,1).chl(k));
        MVP(n,1).lopc(i,:) = nanmean(MVPd(n,1).lopc(k));
    end
end

%% Save the data

save '/Users/scraig/Documents/Ross Sea/MVP/MVP_RossSea2011_2012_despiked' MVP

%% Plot

% for n = 1:length(MVP)
%     hl1 = plot(MVP(n,1).temp, MVP(n,1).pres, 'b', 'Linewidth', 1.5);
%     
%     ax1 = gca;
%     set(ax1,'XMinorTick','on', 'ydir','reverse', 'box','on','xcolor',get(hl1,'color'))
%     xlabel('Temperature')
%     ylabel('Depth (m)')
%     
%     % Add 1st floating axis for the second parameter plotted
%     [hl2,ax2,ax3] = floatAxisX(MVP(n,1).cond, MVP(n,1).pres, 'r','Conductivity');
%     set(ax2,'ydir','reverse')
%     set(hl2, 'Linewidth', 1.5)
%     
%     % Add 2nd floating axis for the third parameter plotted
%     [hl3,ax4,ax5] = floatAxisX(MVP(n,1).sal, MVP(n,1).pres,'k','Salinity');
%     set(ax4,'ydir','reverse')
%     set(hl3, 'Linewidth', 1.5)
%     
%     % Add 2nd floating axis for the third parameter plotted
%     [hl6,ax7,ax8] = floatAxisX(MVP(n,1).sigmat, MVP(n,1).pres,'m','SigmaT');
%     set(ax7,'ydir','reverse')
%     set(hl6, 'Linewidth', 1.5)
%     
%     th = suptitle(datestr(MVP(n,1).daten));
%     set(th, 'FontSize', 16)
%         
%     figure_size(20, 35, 'centimeters')
%     
%     pause
%     close all
%     figure
% end

